@@ -473,6 +473,12 @@ class NotNumpyError(Exception):
         self.message = message
         super().__init__(self.message)
 
+class NotVectorError(Exception):
+    def __init__(self, array, message = "Input is not a vector"):
+        self.array = array
+        self.message = message
+        super().__init__(self.message)
+
 class SigLevelNotInRangeError(Exception):
     def __init__(self, siglev, message = "Significance level not in (0, 1)" \
             "range"):
@@ -511,26 +517,57 @@ class Bluecat:
     def __init__(self, qsim, qcalib, 
         qcalibobs, m, siglev, estmethod, 
         qobs = None, prob_plot = False):
-        if not type(qsim).__module__ == np.__name__:
-            raise NotNumpyError(qsim)
-        elif not type(qcalib).__module__ == np.__name__:
-            raise NotNumpyError(qcalib)
-        elif not type(qcalibobs).__module__ == np.__name__:
-            raise NotNumpyError(qcalibobs)
-        elif not 0 < siglev < 1:
+        
+        if not 0 < siglev < 1:
             raise SigLevelNotInRangeError(siglev)
         elif qobs is None and prob_plot == True:
             raise NoObservedDataError()
-        self.qsim = qsim
-        self.qcalib = qcalib
-        self.qcalibobs = qcalibobs
+        self.qsim = self._pre_array(qsim)
+        self.qcalib = self._pre_array(qcalib)
+        self.qcalibobs = self._pre_array(qcalibobs)
         self.m = m
         self.siglev = siglev
         self.estmethod = estmethod
-        self.qobs = qobs
+        self.qobs = self._pre_array(qobs, optional=True)
         self.prob_plot = prob_plot
-
     
+    @staticmethod
+    def _pre_array(array, optional=False):
+        """Checks if input array is a vector, else raise error.
+        Also, squeezes if array is (n,1) or (1,n) to (n,).
+
+        Args:
+            array (ndarray | None): Input array to check.
+            optional (bool): Asks if the array was optional to bluecat.
+
+        Returns: 
+            An (n,) array or None (if array is not supplied and optional).
+
+        Raises:
+            NotNumpyError: If input array is not a numpy array.
+            NotVectorError: If input array is not a vector.
+
+        """
+        if optional is True and array is None:
+            # check if the optional array is none
+            return array
+        elif not type(array).__module__ == np.__name__:
+            # check if array is numpy, if not raise error
+            raise NotNumpyError(array)
+        elif array.ndim == 1:
+            # check if array is vector
+            return array
+        elif array.ndim == 2:
+            # if array is (n,1) or (1,n) then return the squeezed array, else
+            # raise error
+            if array.shape[0] == 1 or array.shape[1] == 1:
+                return np.squeeze(array)
+            else:
+                raise NotVectorError(array)
+        else:
+            # raise error if none of the above dont match
+            raise NotVectorError(array)
+          
     @staticmethod
     def ppoints(n):
         """Generates probability points. 
